Glossary
--------

instance:
   An example from a category. My cat is an instance of the category
   “feline things.” Every object is an instance of some type.

instance variable:
   One of the named data items that make up an structure. Each structure
   has its own copy of the instance variables for its type.

constant reference parameter:
   A parameter that is passed by reference but that cannot be modified.

pure function:
   A function whose result depends only on its parameters, and that has
   so effects other than returning a value.

functional programming style:
   A style of program design in which the majority of functions are
   pure.

modifier:
   A function that changes one or more of the objects it receives as
   parameters, and usually returns ``void``.

fill-in function:
   A function that takes an “empty” object as a parameter and fills in
   its instance variables instead of generating a return value.

algorithm:
   A set of instructions for solving a class of problems by a
   mechanical, unintelligent process.


.. dragndrop:: chapter_nine_glossary_one
    :feedback: Try again!
    :match_1: instance|||An example from a category. My cat is an instance of the category “feline things.” Every object is an instance of some type.
    :match_2: instance variable|||One of the named data items that make up an structure. Each structure has its own copy of the instance variables for its type.
    :match_3: constant reference parameter|||A parameter that is passed by reference but that cannot be modified.
    :match_4: pure function|||A function whose result depends only on its parameters, and that has so effects other than returning a value.

    Match the definition to the term.

.. dragndrop:: chapter_nine_glossary_two
    :feedback: Try again!
    :match_1: functional programming style|||A style of program design in which the majority of functions are pure.
    :match_2: modifier|||A function that changes one or more of the objects it receives as parameters, and usually returns void.
    :match_3: fill-in function|||A function that takes an “empty” object as a parameter and fills it its instance variables instead of generating a return value.
    :match_4: algorithm|||A set of instructions for solving a class of problems by a mechanical, unintelligent process.

    Match the definition to the term.
